summaryrefslogtreecommitdiff
path: root/Makefile.SH
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2000-02-15 22:59:59 +0000
committerJarkko Hietaniemi <jhi@iki.fi>2000-02-15 22:59:59 +0000
commitc13fdd862cdcd2a9001523a3b81e435228302b74 (patch)
treeac1c482324157204ad30232427e04f289c50cd72 /Makefile.SH
parent2ac48f3aebb413a18125358a7f8d80df97683f4b (diff)
parentbf6c18a67788ecf9349406ba580392adaec98958 (diff)
downloadperl-c13fdd862cdcd2a9001523a3b81e435228302b74.tar.gz
Integrate with Sarathy.
p4raw-id: //depot/cfgperl@5114
Diffstat (limited to 'Makefile.SH')
-rw-r--r--Makefile.SH33
1 files changed, 19 insertions, 14 deletions
diff --git a/Makefile.SH b/Makefile.SH
index 4cfba37d44..1646478bc0 100644
--- a/Makefile.SH
+++ b/Makefile.SH
@@ -597,24 +597,29 @@ SYMH = perlvars.h intrpvar.h thrdvar.h
CHMOD_W = chmod +w
# The following files are generated automatically
# keywords.h: keywords.pl
# opcode.h: opcode.pl
# pp_proto.h: opcode.pl
# pp.sym: opcode.pl
# embed.h: embed.pl [* needs pp.sym generated by opcode.pl! *]
# embedvar.h: embed.pl [* needs pp.sym generated by opcode.pl! *]
# ext/ByteLoader/byterun.h: bytecode.pl
# ext/ByteLoader/byterun.c: bytecode.pl
# ext/B/Asmdata.pm: bytecode.pl
# global.sym: embed.pl
# regnodes.h: regcomp.pl
# warnings.h lib/warnings.pm: warnings.pl
# The correct versions should be already supplied with the perl kit,
# in case you don't have perl available.
-# To force them to run, type
+# To force them to be regenerated, type
# make regen_headers
+
+AUTOGEN_FILES = keywords.h opcode.h opnames.h pp_proto.h pp.sym embed.h \
+ embedvar.h global.sym pod/perlintern.pod pod/perlapi.pod \
+ objXSUB.h perlapi.h perlapi.c ext/ByteLoader/byterun.h \
+ ext/ByteLoader/byterun.c ext/B/B/Asmdata.pm regnodes.h \
+ warnings.h lib/warnings.pm
+
regen_headers: FORCE
- $(CHMOD_W) proto.h warnings.h lib/warnings.pm
+ $(CHMOD_W) $(AUTOGEN_FILES)
perl keywords.pl
perl opcode.pl
perl embed.pl
@@ -597,24 +597,29 @@ SYMH = perlvars.h intrpvar.h thrdvar.h
CHMOD_W = chmod +w
# The following files are generated automatically
-# keywords.h: keywords.pl
-# opcode.h: opcode.pl
-# pp_proto.h: opcode.pl
-# pp.sym: opcode.pl
-# embed.h: embed.pl [* needs pp.sym generated by opcode.pl! *]
-# embedvar.h: embed.pl [* needs pp.sym generated by opcode.pl! *]
-# ext/ByteLoader/byterun.h: bytecode.pl
-# ext/ByteLoader/byterun.c: bytecode.pl
-# ext/B/Asmdata.pm: bytecode.pl
-# global.sym: embed.pl
-# regnodes.h: regcomp.pl
-# warnings.h lib/warnings.pm: warnings.pl
+# keywords.pl: keywords.h
+# opcode.pl: opcode.h opnames.h pp_proto.h pp.sym
+# [* embed.pl needs pp.sym generated by opcode.pl! *]
+# embed.pl: proto.h embed.h embedvar.h global.sym objXSUB.h
+# perlapi.h perlapi.c pod/perlintern.pod
+# pod/perlapi.pod
+# bytecode.pl: ext/ByteLoader/byterun.h ext/ByteLoader/byterun.c
+# ext/B/B/Asmdata.pm
+# regcomp.pl: regnodes.h
+# warnings.pl: warnings.h lib/warnings.pm
# The correct versions should be already supplied with the perl kit,
# in case you don't have perl available.